@@ -3,6 +3,8 @@ from ..ast_funcs import get_el_lines_dets
 from .. import conf, utils
 from ..utils import layout_comment
 
+FUNC_DEFN_XPATH = 'descendant-or-self::FunctionDef'
+
 def _get_arg_comment(func_el, *, repeated_message=False):
     """
     Must cope with positional arguments, keyword arguments, keyword-only
@@ -106,14 +108,14 @@ def _get_exit_comment(func_el, *, repeated_message=False):
             return_elements, repeated_message=repeated_message)
     return exit_comment
 
-@filt_block_advisor(xpath='body/FunctionDef')
+@filt_block_advisor(xpath=FUNC_DEFN_XPATH)
 def func_overview(block_dets, *, repeated_message=False):
     """
     Advise on function definition statements. e.g. def greeting(): ...
     """
-    func_els = block_dets.element.xpath('descendant-or-self::FunctionDef')
+    func_els = block_dets.element.xpath(FUNC_DEFN_XPATH)
     brief_comment = layout_comment("""\
-        #### Function Details
+        ### Function Details
         """)
     for func_el in func_els:
         name = func_el.get('name')
@@ -141,31 +143,35 @@ def func_overview(block_dets, *, repeated_message=False):
     }
     return message
 
-@filt_block_advisor(xpath='body/FunctionDef', warning=True)
+@filt_block_advisor(xpath=FUNC_DEFN_XPATH, warning=True)
 def func_len_check(block_dets, *, repeated_message=False):
     """
     Warn about functions that might be too long.
     """
-    func_els = block_dets.element.xpath('descendant-or-self::FunctionDef')
+    func_els = block_dets.element.xpath(FUNC_DEFN_XPATH)
     brief_comment = ''
     has_short_comment = False
     for func_el in func_els:
         name = func_el.get('name')
-        _first_line_no, _last_line_no, func_lines_n = get_el_lines_dets(
+        first_line_no, last_line_no, _func_lines_n = get_el_lines_dets(
             func_el, ignore_trailing_lines=True)
+        block_lines = block_dets.block_code_str.split('\n')
+        func_lines = block_lines[first_line_no - 1: last_line_no]
+        func_non_empty_lines = [line for line in func_lines if line]
+        func_lines_n = len(func_non_empty_lines)
         if func_lines_n <= conf.MAX_BRIEF_FUNC_LOC:
             continue
         else:
             if not has_short_comment:
                 brief_comment += layout_comment("""\
-                    #### Function possibly too long
+                    ### Function possibly too long
 
                     """)
                 has_short_comment = True
             brief_comment += layout_comment(f"""\
 
             `{name}` has {utils.int2nice(func_lines_n)} lines of code
-            (including comments).
+            (including comments but with empty lines ignored).
             """)
             if not repeated_message:
                 brief_comment += (" Sometimes it is OK for a function to be "
@@ -184,12 +190,12 @@ def get_n_args(func_el):
     n_args = len(arg_els + kwonlyarg_els)
     return n_args
 
-@filt_block_advisor(xpath='body/FunctionDef', warning=True)
+@filt_block_advisor(xpath=FUNC_DEFN_XPATH, warning=True)
 def func_excess_parameters(block_dets, *, repeated_message=False):
     """
     Warn about functions that might have too many parameters.
     """
-    func_els = block_dets.element.xpath('descendant-or-self::FunctionDef')
+    func_els = block_dets.element.xpath(FUNC_DEFN_XPATH)
     brief_comment = ''
     has_high = False
     for func_el in func_els:
@@ -198,7 +204,7 @@ def func_excess_parameters(block_dets, *, repeated_message=False):
         high_args = n_args > conf.MAX_BRIEF_FUNC_ARGS
         if high_args:
             brief_comment += layout_comment("""\
-                #### Possibly too many function parameters
+                ### Possibly too many function parameters
 
                 """)
             brief_comment += layout_comment(f"""\
@@ -247,7 +253,7 @@ def get_danger_args(func_el):
         if danger_status is not None]
     return danger_args
 
-@filt_block_advisor(xpath='body/FunctionDef', warning=True)
+@filt_block_advisor(xpath=FUNC_DEFN_XPATH, warning=True)
 def positional_boolean(block_dets, *, repeated_message=False):
     """
     Look for any obvious candidates for forced keyword use e.g. where a
@@ -256,7 +262,7 @@ def positional_boolean(block_dets, *, repeated_message=False):
     Defaults apply from the rightmost backwards (within their group - either
     defaults or kw_defaults (related to kwonlyargs)).
     """
-    func_els = block_dets.element.xpath('descendant-or-self::FunctionDef')
+    func_els = block_dets.element.xpath(FUNC_DEFN_XPATH)
     brief_comment = ''
     has_positional_comment = False
     for func_el in func_els:
@@ -266,7 +272,7 @@ def positional_boolean(block_dets, *, repeated_message=False):
             if not has_positional_comment:
                 brief_comment += layout_comment("""\
 
-                    #### Function expects risky positional arguments
+                    ### Function expects risky positional arguments
                     """)
                 if not repeated_message:
                     brief_comment += layout_comment("""\
@@ -361,12 +367,13 @@ def get_funcs_dets_and_docstring(func_els):
         funcs_dets_and_docstring.append(func_dets_and_docstring)
     return funcs_dets_and_docstring
 
-@filt_block_advisor(xpath='body/FunctionDef', warning=True)
+@filt_block_advisor(xpath=FUNC_DEFN_XPATH, warning=True)
 def docstring_issues(block_dets, *, repeated_message=False):
     """
     Check over function doc strings. Missing doc string, not enough lines to
     cover params, return etc.
     """
+    WRAPPING_NEWLINE_N = 2
     example_docstring = layout_comment(f'''\
         def greet(name, greet_word='Hi'):
             """
@@ -380,7 +387,7 @@ def docstring_issues(block_dets, *, repeated_message=False):
             greeting = f"{{greet_word}} {{name}} - how are you?"
             return greeting
         ''', is_code=True)
-    func_els = block_dets.element.xpath('descendant-or-self::FunctionDef')
+    func_els = block_dets.element.xpath(FUNC_DEFN_XPATH)
     funcs_dets_and_docstring = get_funcs_dets_and_docstring(func_els)
     brief_comment = ''
     missing_commented = False
@@ -390,7 +397,7 @@ def docstring_issues(block_dets, *, repeated_message=False):
             if not (missing_commented or repeated_message):
                 brief_comment += (
                     layout_comment(f"""\
-                        #### Function missing doc string
+                        ### Function missing doc string
 
                         `{func_name}` lacks a doc string - you should probably
                         add one.
@@ -418,14 +425,14 @@ def docstring_issues(block_dets, *, repeated_message=False):
                     """)
         else:
             n_args = get_n_args(func_el)
-            n_doc_lines = len(docstring.split(conf.LINE_FEED))
+            n_doc_lines = len(docstring.split('\n')) - WRAPPING_NEWLINE_N
             too_short = n_doc_lines < (conf.MIN_BRIEF_DOCSTRING + n_args)
             param_str = ' given the number of parameters' if n_args > 1 else ''
             if too_short:
                 if not (inadequate_commented or repeated_message):
                     brief_comment += (
                         layout_comment(f"""\
-                            #### Function doc string too brief?
+                            ### Function doc string too brief?
 
                             The doc string for {func_name} seems a little
                             short{param_str}. You might want to rework it. Here
