@@ -17,24 +17,26 @@ IF_XPATH = 'descendant-or-self::If'
 
 def add_if_details(if_element, if_clauses):
     """
-    If under our <If>'s <orelse> we have another <If> store an 'elif' in if_details
-    and send the <If> under <orelse> through again; otherwise store an 'else'
-    in if_details and return.
+    If under our <If>'s <orelse> we have another <If>, and it is the only child,
+    store an 'elif' in if_details and send the <If> under <orelse> through
+    again (the AST nests them even though they are siblings in the original code
+    syntax); otherwise store an 'else' in if_details and return.
 
-    <If>s have <orelse>s which either have <If>s or not. When there is not then
-    we have reached else.
+    <If>s have <orelse>s which either have sole <If>s or not. When there is not
+    then we have reached else.
     """
-    orelse_has_children = bool(if_element.xpath('orelse')[0].getchildren())  ## always has one but if merely an <If> has no children under orelse
-    if not orelse_has_children:
-        return
-    try:
-        if_element_under_if = if_element.xpath('orelse/If')[0]
-        has_elif = True
-    except IndexError:
-        has_elif = False
+    orelse_el = if_element.xpath('orelse')[0]  ## always has one
+    orelse_children = orelse_el.getchildren()
+    if not orelse_children:
+        return  ## merely an If on its own without clauses
+    ## else: if or elif: ?
+    just_the_if_under_orelse = (
+        len(orelse_children) == 1 and orelse_children[0].tag == 'If')
+    has_elif = just_the_if_under_orelse
     if has_elif:
         if_clauses.append(ELIF)
-        add_if_details(if_element_under_if, if_clauses)
+        elif_el = orelse_children[0]
+        add_if_details(elif_el, if_clauses)
     else:
         if_clauses.append(ELSE)
     return
@@ -43,6 +45,26 @@ def get_ifs_details(block_dets):
     """
     There can be multiple if statements in a snippet so we have to handle each
     of them.
+
+    And in AST the following are very similar:
+
+    if foo:
+        ...
+    else:
+        if bar:
+            ...
+
+    if foo:
+        ...
+    elif bar:
+        ...
+
+    They both result in:
+    <orelse>
+        <If ...>
+
+    So need to look under the 'orelse' for anything other than an 'If' to decide
+    whether an 'else' or 'elif'.
     """
     ## skip when if __name__ == '__main__'
     if block_dets.block_code_str.startswith("if __name__ == "):
@@ -51,8 +73,11 @@ def get_ifs_details(block_dets):
     if_elements = []
     for raw_if_el in raw_if_els:
         ## ignore if really an elif
-        has_or_else_parent = raw_if_el.getparent().tag == 'orelse'
-        if not has_or_else_parent:
+        parent_el = raw_if_el.getparent()
+        has_or_else_parent = (parent_el.tag == 'orelse')
+        has_siblings = bool(parent_el.getchildren())
+        actually_elif = (has_or_else_parent and not has_siblings)
+        if not actually_elif:
             if_elements.append(raw_if_el)
     ifs_details = []
     for if_element in if_elements:
@@ -73,24 +98,27 @@ def _get_if_comment(ifs_details):
     Have to cope with multiple if statements and make it nice (unnumbered) when
     only one.
     """
-    brief_comment = '#### Conditional statement detected'
+    brief_comment = '### Conditional statement detected'
     for n, if_details in enumerate(ifs_details, 1):
         counter = '' if len(ifs_details) == 1 else f" {int2nice(n)}"
         if if_details.multiple_conditions:
             n_elifs = if_details.if_clauses.count(ELIF)
             brief_comment += layout_comment(f"""\
 
-                `if` statement{counter} has {int2nice(n_elifs)} `elif`
-                clauses
+                `if` statement{counter} has {int2nice(n_elifs)} `elif` clauses
                 """)
             if if_details.missing_else:
                 brief_comment += " and no `else` clause."
             else:
                 brief_comment += " and an `else` clause."
+            brief_comment += (
+                " Note - `else` clauses with an `if`, and only an `if`, "
+                "underneath count as `elif` clauses not `else` clauses.")
         else:
             brief_comment += layout_comment(f"""\
 
-                `if` statement{counter} has no extra conditions.
+                `if` statement{counter} has no extra clauses e.g. `elif`s or an
+                `else`.
                 """)
     return brief_comment
 
@@ -159,14 +187,18 @@ def missing_else(block_dets, *, repeated_message=False):
         if first:
             brief_comment += layout_comment(f"""\
 
-                #### Missing `else` clause
+                ### Possibly better with `else` clause
 
                 """)
         if first and not repeated_message:
             brief_comment += layout_comment(f"""\
                 `if` block{counter} has `elif` clauses but lacks an `else`
-                clause. It is often best to include an `else` clause when there
-                are `elif` clauses.
+                clause. If your `elif` clauses are trying to handle all expected
+                cases it is probably best to include an `else` clause as well
+                just in case something unexpected happens.
+
+                Note - `else` clauses with an `if` and only the `if` underneath
+                count as `elif` clauses.
                 """)
         has_missing_else = True
     if not has_missing_else:
@@ -321,7 +353,7 @@ def split_group_membership(block_dets, *, repeated_message=False):
         return None
     brief_comment = layout_comment(f"""\
 
-            #### Possible option of evaluating group membership
+            ### Possible option of evaluating group membership
 
             It looks like `{comp_var}` has been in multiple separate
             comparisons. In Python it is possible to do a simple check of group
@@ -420,7 +452,7 @@ def implicit_boolean_enough(block_dets, *, repeated_message=False):
     brief_comment = (
         layout_comment("""\
 
-            #### Possible option of using an implicit boolean
+            ### Possible option of using an implicit boolean
 
             In Python, "", 0, [], {}, (), `None` all evaluate to False when we
             ask if they are `True` or `False`. And they all evaluate to `True`
