@@ -5,6 +5,8 @@ from ..utils import layout_comment
 
 ASSIGN_LIST_XPATH = 'descendant-or-self::Assign/value/List'
 
+DEFAULT_EXAMPLE_TYPE = conf.STR_TYPE
+
 def get_item_type_names(items):
     item_type_names = sorted(set(
         [type(item).__name__ for item in items]
@@ -14,21 +16,37 @@ def get_item_type_names(items):
         for item_type in item_type_names]
     return item_type_names, item_type_nice_names
 
+def get_type_for_example(list_items):
+    """
+    If all else fails, just use strings for examples.
+    """
+    if list_items is None:
+        type4example = DEFAULT_EXAMPLE_TYPE
+    else:
+        item_type_names, _item_type_nice_names = get_item_type_names(list_items)
+        try:
+            type4example = item_type_names.pop()
+        except IndexError:
+            type4example = DEFAULT_EXAMPLE_TYPE
+    return type4example
+
 def _get_additional_main_comment(first_name, first_list_items):
-    item_type_names, _item_type_nice_names = get_item_type_names(
-        first_list_items)
-    try:
-        type4example = item_type_names.pop()
-    except IndexError:
-        type4example = conf.STR_TYPE
+    """
+    :param list first_list_items: note - may be None if a list is defined in a
+     function
+    """
+    type4example = get_type_for_example(first_list_items)
     try:
         example_items = conf.EXAMPLES_OF_TYPES[type4example]
     except KeyError:
-        example_items = conf.EXAMPLES_OF_TYPES[conf.STR_TYPE]
+        example_items = conf.EXAMPLES_OF_TYPES[DEFAULT_EXAMPLE_TYPE]
     example_item = example_items[0]
     listable_example_item = (f"'{example_item}'"
         if type4example == conf.STR_TYPE else example_item)
-    appended_list = first_list_items.copy()
+    if first_list_items is None:
+        appended_list = []
+    else:
+        appended_list = first_list_items.copy()
     appended_list.append(example_item)
     extended_list = appended_list.copy()
     items2extend = example_items[1:3]  ## don't repeat the appended item - might confuse the user at this stage
@@ -145,23 +163,33 @@ def list_overview(block_dets, *, repeated_message=False):
     for i, list_el in enumerate(list_els):
         first = (i == 0)
         name = get_assign_name(list_el)
-        items = code_execution.get_val(
+        items = code_execution.get_val(  ## might be None if defined in a function
             block_dets.pre_block_code_str, block_dets.block_code_str, name)
         if first:
             first_name = name
             first_list_items = items
             title = layout_comment(f"""\
-    
-                #### List{plural} defined
+
+                ### List{plural} defined
     
                 """)
             brief_comment += title
             main_comment += title
+        if items is None:
+            list_desc = layout_comment(f"""\
 
-        list_desc = layout_comment(f"""\
+                `{name}` is a list.
+                """)
+        elif items == []:
+            list_desc = layout_comment(f"""\
 
-            `{name}` is a list with {utils.int2nice(len(items))} items.
-            """)
+                `{name}` is an empty list.
+                """)
+        else:
+            list_desc = layout_comment(f"""\
+    
+                `{name}` is a list with {utils.int2nice(len(items))} items.
+                """)
         brief_comment += list_desc
         main_comment += list_desc
     if not repeated_message:
@@ -193,8 +221,10 @@ def mixed_list_types(block_dets, *, repeated_message=False):  # @UnusedVariable
     for i, list_el in enumerate(list_els):
         first = (i == 0)
         name = get_assign_name(list_el)
-        items = code_execution.get_val(
+        items = code_execution.get_val(  ## might be None if defined in a function
             block_dets.pre_block_code_str, block_dets.block_code_str, name)
+        if not items:
+            continue
         _item_type_names, item_type_nice_names = get_item_type_names(items)
         if len(item_type_nice_names) <= 1:
             ## No explanation needed if there aren't multiple types.
@@ -202,7 +232,7 @@ def mixed_list_types(block_dets, *, repeated_message=False):  # @UnusedVariable
         has_mixed = True
         if first:
             title = layout_comment(f"""\
-                #### List(s) with mix of different data types
+                ### List(s) with mix of different data types
     
                 """)
             brief_comment += title
