@@ -16,12 +16,11 @@ STR_ADDITION_XPATH = 'descendant-or-self::BinOp/left/Str'  ## each left has a ri
 F_STR_REMINDER = False
 
 @filt_block_advisor(xpath=ASSIGN_STR_XPATH)
-def str_overview(block_dets, *, repeated_message=False):
+def assigned_str_overview(block_dets, *, repeated_message=False):
     """
     Provide overview of assigned strings e.g. name = 'Hamish'.
     """
     brief_comment = ''
-    main_comment = ''
     str_els = block_dets.element.xpath(ASSIGN_STR_XPATH)
     first_name = None
     first_val = None
@@ -34,51 +33,59 @@ def str_overview(block_dets, *, repeated_message=False):
         if first:
             first_name = name
             first_val = val
-            title = layout_comment("""\
+            brief_comment += layout_comment("""\
 
-                ##### String Overview
+                #### String Overview
 
                 """)
-            brief_comment += title
-            main_comment += title
-        desc_comment = layout_comment(f"""\
+        brief_comment += layout_comment(f"""\
             `{name}` is a string.
 
             """)
-        brief_comment += desc_comment
-        main_comment += desc_comment
     if repeated_message:
+        main_comment = brief_comment
         extra_comment = ''
     else:
         brief_comment += layout_comment(f"""\
             Python makes it easy to do lots of cool things with strings.
-            E.g. {first_name}.upper() returns {first_val.upper()}.
+
+            """)
+        if first_val:
+            name2use = first_name
+            val2use = first_val
+        else:
+            name2use = 'address'
+            val2use = 'Waiuku, New Zealand'
+            brief_comment += layout_comment(f"""\
+                For illustration, imagine we have string '{val2use}' assigned to
+                `{name2use}`:
+
+                """)
+        main_comment = brief_comment  ## after this brief and main diverge
+        brief_comment += layout_comment(f"""\
+            {name2use}.upper() returns {val2use.upper()}.
 
             """)
         black_heart = "\N{BLACK HEART}"
         main_comment += layout_comment(f"""\
-                Python makes it easy to do lots of cool things with strings.
+            Examples:
 
-                Examples:
+            {name2use}.upper() returns {val2use.upper()}.
 
-                {first_name}.upper() returns {first_val.upper()}.
+            {name2use}.center(70, '=') returns {val2use.center(70, '=')}
 
-                {first_name}.center(70, '=') returns {first_val.center(70, '=')}
+            {name2use}.endswith('chicken') returns {val2use.endswith('chicken')}
 
-                {first_name}.endswith('chicken') returns
-                {first_val.endswith('chicken')}
+            {name2use} + ' is a string' returns {val2use + ' is a string'}
 
-                {first_name} + ' is a string' returns
-                {first_val + ' is a string'}
+            {name2use} + ' ' + '{{\\NBLACK HEART}}' + ' Python' returns
+            {val2use + ' ' + black_heart + ' Python'}
 
-                {first_name} + ' ' + '{{\\NBLACK HEART}}' + ' Python' returns
-                {first_val + ' ' + black_heart + ' Python'}
+            len({name2use}) returns {len(val2use)} because that is how many
+            characters are in the {name2use} string (remember to count spaces -
+            they are characters too)
 
-                len({first_name}) returns {len(first_val)} because that is how
-                many characters are in the {first_name} string (remember to
-                count spaces - they are characters too)
-
-                sorted({first_name}) returns {sorted(first_val)}
+            sorted({name2use}) returns {sorted(val2use)}
             """)
         extra_comment = layout_comment("""\
             .upper(), .center() etc are abilities available with all Python
@@ -100,12 +107,18 @@ def str_overview(block_dets, *, repeated_message=False):
     }
     return message
 
-def str_combination(combination_type, assign_els, *, repeated_message=False):
+def str_combination(combination_type, str_els, *, repeated_message=False):
     global F_STR_REMINDER
     brief_comment = ''
     title = None
-    for assign_el in assign_els:
-        name = assign_el.xpath('targets/Name')[0].get('id')
+    for str_el in str_els:
+        try:
+            assign_el = str_el.xpath('ancestor::Assign')[-1]
+        except IndexError:
+            name = "An unnamed string"
+        else:
+            raw_name = assign_el.xpath('targets/Name')[0].get('id')
+            name = f"`{raw_name}`"
         combination_type2comment = {
             F_STR: "f-string interpolation",
             STR_FORMAT_FUNC: "the format function",
@@ -116,12 +129,12 @@ def str_combination(combination_type, assign_els, *, repeated_message=False):
         if not title:
             title = layout_comment(f"""\
 
-            #### Strings created by combining or interpolating strings
+            ### Strings created by combining or interpolating strings
             """)
             brief_comment += title
         brief_comment += layout_comment(f"""\
 
-            `{name}` is created using {combination_comment}.
+            {name} is created using {combination_comment}.
             """)
     message = {
         conf.BRIEF: brief_comment,
@@ -189,12 +202,8 @@ def f_str_interpolation(block_dets, *, repeated_message=False):
     Examine f-string interpolation.
     """
     joined_els = block_dets.element.xpath(JOINED_STR_XPATH)
-    assign_els = []
-    for joined_el in joined_els:
-        assign_el = joined_el.xpath('ancestor::Assign')[-1]
-        assign_els.append(assign_el)
     return str_combination(F_STR,
-        assign_els, repeated_message=repeated_message)
+        joined_els, repeated_message=repeated_message)
 
 @filt_block_advisor(xpath=FUNC_ATTR_XPATH)
 def format_str_interpolation(block_dets, repeated_message=False):
@@ -209,12 +218,8 @@ def format_str_interpolation(block_dets, repeated_message=False):
             format_funcs.append(func_attr_el)
     if not format_funcs:
         return None
-    assign_els = []
-    for format_el in format_funcs:
-        assign_el = format_el.xpath('ancestor::Assign')[-1]
-        assign_els.append(assign_el)
     return str_combination(STR_FORMAT_FUNC,
-        assign_els, repeated_message=repeated_message)
+        format_funcs, repeated_message=repeated_message)
 
 @any_block_advisor()
 def sprintf(block_dets, *, repeated_message=False):
@@ -226,12 +231,8 @@ def sprintf(block_dets, *, repeated_message=False):
     has_sprintf = bool(sprintf_els)
     if not has_sprintf:
         return None
-    assign_els = []
-    for sprintf_el in sprintf_els:
-        assign_el = sprintf_el.xpath('ancestor::Assign')[-1]
-        assign_els.append(assign_el)
     return str_combination(SPRINTF,
-        assign_els, repeated_message=repeated_message)
+        sprintf_els, repeated_message=repeated_message)
 
 @any_block_advisor()
 def string_addition(block_dets, *, repeated_message=False):
@@ -241,7 +242,7 @@ def string_addition(block_dets, *, repeated_message=False):
     """
     str_els_being_combined = block_dets.element.xpath(STR_ADDITION_XPATH)
     has_string_addition = False
-    assign_els = []
+    str_addition_els = []
     for str_el in str_els_being_combined:
         ## Does their immediate ancestor BinOp have op of Add?
         ## Don't know if there any alternatives but let's be sure
@@ -250,11 +251,10 @@ def string_addition(block_dets, *, repeated_message=False):
         ## was it an Add op
         has_add = bool(bin_op_el.xpath('op/Add'))
         if has_add:
+            str_addition_els.append(str_el)
             has_string_addition = True
-            assign_el = bin_op_el.xpath('ancestor::Assign')[-1]
-            assign_els.append(assign_el)
     if not has_string_addition:
         return None
     addition_message = str_combination(STR_ADDITION,
-        assign_els, repeated_message=repeated_message)
+        str_addition_els, repeated_message=repeated_message)
     return addition_message
