@@ -2,7 +2,10 @@ import datetime
 import logging
 from pathlib import Path
 
-DEV_MODE = False  ## updates AST output each run
+LOG_LEVEL = logging.INFO
+RECORD_AST = False
+
+DEV_MODE = False
 
 if DEV_MODE:
     print("""\
@@ -14,8 +17,8 @@ if DEV_MODE:
 
 
     """)
-
-LOG_LEVEL = logging.DEBUG if DEV_MODE else logging.INFO
+    LOG_LEVEL = logging.DEBUG
+    RECORD_AST = True
 
 ## When testing user-supplied snippets watch out for the BOM MS inserts via Notepad. AST chokes on it.
 
@@ -26,12 +29,10 @@ def sorted(my_list):
 """
 
 TEST_SNIPPET = """\
-n = -1
-for image in images:
-    if n % 10 == 0:
-        print(f"Just processed image {{n}}")
-    process_image(image)
-    n += 1
+for person in persons:
+    for pet in pets:
+        for year in years:
+            print(f"{person} might like a {pet} in {year}")
 """
 
 DEMO_SNIPPET = """\
@@ -208,10 +209,15 @@ EXAMPLES_OF_TYPES = {  ## best to include at least three so we have enough to ap
 MAX_BRIEF_FUNC_LOC = 35
 MAX_BRIEF_FUNC_ARGS = 6
 MIN_BRIEF_DOCSTRING = 3
+MIN_BRIEF_NAME = 3
 
 NO_ADVICE_MESSAGE = ("No advice to give - looks fine :-). But if you think "
     "there should have been some advice given, contact grant@p-s.co.nz with "
-    "the subject line 'Advice' and explain. Include a snippet to test as well.")
+    "the subject line 'Advice' and explain. Please include a snippet to test as"
+    " well.")
+MISSING_ADVICE_MESSAGE = ("If there was some advice you think should have been "
+    "given that wasn't, contact grant@p-s.co.nz with the subject line 'Advice' "
+    "and explain. Please include a snippet to test as well.")
 SYSTEM_MESSAGE = 'System message'
 
 LINE_FEED = '&#10;'
