@@ -97,7 +97,7 @@ def get_message_dets_from_input(advisor_dets, *,
         message = {
             conf.BRIEF: (
                 layout_comment(f"""\
-                    #### Advisor "`{name}`" unable to run
+                    ### Advisor "`{name}`" unable to run
 
                     Advisor {name} unable to run. Advisor description:
                     """)
@@ -211,8 +211,17 @@ def get_separated_messages_dets(snippet):
     """
     tree = get_tree(snippet)
     xml = astpath.asts.convert_to_xml(tree)
-    if conf.DEV_MODE:
+    if conf.RECORD_AST:
         xml.getroottree().write(str(conf.AST_OUTPUT_XML), pretty_print=True)
+        logging.info("""\
+
+
+
+        Updating AST
+
+
+
+        """)
     snippet_lines = snippet.split('\n')
     blocks_dets = get_blocks_dets(xml, snippet_lines)
     overall_snippet_messages_dets = get_overall_snippet_messages_dets(
@@ -241,7 +250,7 @@ def get_error_messages_dets(e, snippet):
     """
     message = {
         conf.BRIEF: layout_comment(f"""\
-            #### No advice sorry :-(
+            ### No advice sorry :-(
 
             Unable to provide advice - some sort of problem.
 
